.App{background:radial-gradient(circle farthest-corner at top,#f0f0f0 5em,#c6c6c6 60em);text-align:center;min-height:100vh;display:inline-block;min-width:100vw}.App-logo{height:10em}.App-header{height:15em;padding:20px;color:#000}.App-leaderboard{width:65%;min-width:32em;color:#fff;padding:1em;line-height:2em;margin-left:auto;margin-right:auto}.App-leaderboard-column-0{width:10%}.App-leaderboard-column-1{width:40%}.App-leaderboard-column-2,.App-leaderboard-column-3,.App-leaderboard-column-4{width:15%}.App-leaderboard-header-row{text-align:center}.App-leaderboard-header-cell{border-radius:.5em;background:#32343f;height:2.2em}.App-leaderboard-data-group{display:table-row-group}.App-leaderboard-data-row{display:table-row;margin-top:.2em;margin-bottom:.2em}.App-leaderboard-data-cell{vertical-align:middle;height:2em;border-radius:.5em;padding-left:1em;padding-right:1em}.App-leaderboard-centre-aligned-cell{text-align:center}.App-leaderboard-right-aligned-cell{text-align:right}.App-leaderboard-left-aligned-cell{text-align:left}.App-leaderboard-data-cell-protoss{background:#50a050}.App-leaderboard-data-cell-zerg{background:#a05050}.App-leaderboard-data-cell-terran{background:#5050a0}.App-leaderboard-data-cell-random{background:#a0a050}.App-leaderboard-data-cell-tier{background:#32343f}.App-leaderboard-data-break{display:table-cell;width:100vw;text-align:center;color:#000;vertical-align:middle;height:5em}.App-leaderboard-race-icon{height:1.5em;vertical-align:middle;filter:invert(100%)}.App-leaderboard-league-emblem{height:1.5em;vertical-align:middle;filter:brightness(130%);padding-left:.5em;padding-right:.5em}.App-leaderboard-league-name{text-transform:capitalize}body{margin:0;padding:0;font-family:sans-serif}
/*# sourceMappingURL=main.39fc96a2.css.map*/